==> free-sa-1.4.3.tar.gz: free-sa-1.4.3/src/free-sa.cgi.c <==
#include "global.h"


int main(void) {
    FILE *Log;
    char *method, *query;
    time_t mindate, maxdate, ttime;
    char tip[IPSIZE], tname[USERNAMESIZE], tmethod, turl[URLSIZE], tstat, rtr[USERNAMESIZE], stext[128];
    double tBytes, tSeconds;
    short int tcode, tIndic;
    struct SAentry *res;
    char *iname;
    short int i = 1;

    /* Set real time mode for internal functions */
    icfg.Mode = 5;
    
    /* This is required for debug and other purposes */
    fprintf(stdout, "Content-Type: text/html\n\n");
    
    if ((method = getenv("REQUEST_METHOD")) == NULL) SAexit("Incorrect environment: no REQUEST_METHOD");
    if (strcmp(method, "GET")) SAexit("Incorrect request method");
    
    InitLocale();
    InitConfig();
    cfg.UR = cfg.TSR = 0;
    Log = InitLog();
    query = getenv("QUERY_STRING");
    /* If first run (without ldt parameters), then get last log date, else get date from ldt parameter */
    if (query == NULL || query[0] == '\0') ShowLogI(Log, &mindate, &maxdate);
    else {
	if (!strncmp(query, "ldt=", 4L)) {
	    if (sscanf(&query[4], "%ld", &maxdate) != 1) SAexit("Incorrect parameter value specified");
	} else SAexit("Incorrect parameter specified");
    }

    if (SeekLog(Log, maxdate)) SAexit("Log was changed during processing");

    /* RTR: header */
    SAsnprintf(rtr, sizeof(rtr), "%s%s", loc->Connections, loc->InRealTime);
    SAsnprintf(stext, sizeof(stext), "%s (%s)", loc->DnT, loc->Asc);
    SAfopenH("../", 'r', rtr, stext, 0, "w", "");
    /* RTR: table header */
    fprintf(stdout, "\
<tr><td colspan=6 class=gr onclick=\"SAswitchbck();\"><img id=bck src=\"../s.png\" alt=\"\">\n\
<tr><td class=el>\n\
<tr><th>%s<th>%s<th colspan=2>%s<th>%s<th>%s\n\
", loc->No, loc->DnT, loc->User, loc->Bytes, loc->URL);
    /* RTR: write */
    while(READ_RECORD(Log, &ttime, &tSeconds, tip, &tcode, &tBytes, &tmethod, turl, tname, &tstat)) {
	/* Save maximal date as parameter for next cgi call */
	if (ttime > maxdate) maxdate = ttime;
	
        /* Internal name resolution and fix */
        if (!cfg.INameUser || tname[0] == '-') iname = tip;
        else iname = FixFileName(tname);
	
	/* Search for internal name in Users */
        res = ComputeUser(iname, tip);
        tIndic = ComputeIndics(tcode, tmethod, turl, &tstat, iname, tBytes);
        
        fprintf(stdout, "<tr><td>%hd<td>%s<td>%s<td>%s<td>%s<td class=lt><a href=\"%s\">%s</a>", i++, GetDT(ttime, "%x %X"), res->ip, res->vname, icfg.SAB(tBytes), turl, LimitedURL(turl));
        Indics(stdout, tIndic);
    }

    SAfclose(Log, cfg.Log);

    /* Add acript for RTR page autoupdate after timeout */
    fprintf(stdout, "\
<script language=\"JavaScript\" type=\"text/javascript\">\n\
\tvar t;\n\
\tfunction SAupdate() { top.location.href = \"free-sa.cgi?ldt=%ld\"; }\n\
\tfunction SAswitchbck() {\n\
\t\tif (t != 0) { clearTimeout(t); document.getElementById(\"bck\").src='../c.png'; t = 0; }\n\
\t\telse SAupdate();\n\
\t}\n\
\tt = setTimeout('SAupdate()', %ld);\n\
</script>\n", maxdate, cfg.RTRTimeOut);
    
    SAfcloseH(stdout, "");
    
    return(EXIT_SUCCESS);
}

==> free-sa-2.0.0b5.tar.gz: free-sa-2.0.0b5/src/free-sa.cgi.c <==
#include "global.h"


int main(void) {
    FILE *Log;
    char *method, *query;
    time_t mindate, maxdate, ttime;
    char tip[IPSIZE], tname[USERNAMESIZE], tmethod, turl[URLSIZE], tstat, rtr[USERNAMESIZE], stext[128];
    double tBytes, tSeconds;
    short int tcode, tIndic;
    struct SAentry *res;
    char *iname;
    short int i = 1;

    /* Set real time mode for internal functions */
    icfg.Mode = 5;

    /* This is required for debug and other purposes */
    SAfprintf(stdout, "Content-Type: text/html\n\n");

    if ((method = getenv("REQUEST_METHOD")) == NULL) SAexit("Incorrect environment: no REQUEST_METHOD");
    if (strcmp(method, "GET")) SAexit("Incorrect request method");

    InitLocale();
    InitConfig();
    cfg.users_report = cfg.top_sites_report = 0;
    Log = InitLog();
    query = getenv("QUERY_STRING");
    /* If first run (without ldt parameters), then get last log date, else get date from ldt parameter */
    if (query == NULL || query[0] == '\0') ShowLogI(Log, &mindate, &maxdate);
    else {
	if (!strncmp(query, "ldt=", 4L)) {
	    if (sscanf(&query[4], "%ld", &maxdate) != 1) SAexit("Incorrect parameter value specified");
	} else SAexit("Incorrect parameter specified");
    }

    if (SeekLog(Log, maxdate)) SAexit("Log was changed during processing");

    /* RTR: header */
    SAsnprintf(rtr, sizeof(rtr), "%s%s", loc->Connections, loc->InRealTime);
    SAsnprintf(stext, sizeof(stext), "%s (%s)", loc->DnT, loc->Asc);
    SAfopenH("../", 'r', rtr, stext, 0, "");
    /* RTR: table header */
    SAfprintf(stdout, "\
<tr><td colspan=6 class=gr onclick=\"SAswitchbck();\"><img id=bck src=\"../s.png\" alt=\"\">\n\
<tr><td class=el>\n\
<tr><th>%s<th>%s<th colspan=2>%s<th>%s<th>%s\n\
", loc->No, loc->DnT, loc->User, loc->Bytes, loc->URL);
    /* RTR: write */
    while(READ_RECORD(Log, &ttime, &tSeconds, tip, &tcode, &tBytes, &tmethod, turl, tname, &tstat)) {
	/* Save maximal date as parameter for next cgi call */
	if (ttime > maxdate) maxdate = ttime;
	
        /* Internal name resolution and fix */
        if (!cfg.username_is_preferred || tname[0] == '-') iname = tip;
        else iname = FixFileName(tname);
	
	/* Search for internal name in Users */
        res = ComputeUser(iname, tip);
        tIndic = ComputeIndics(tcode, tmethod, turl, tip, &tstat, iname, tBytes);

        SAfprintf(stdout, "<tr><td>%hd<td>%s<td>%s<td>%s<td>%s<td class=lt><a href=\"%s\">%s</a>", i++, GetDT(ttime, "%x %X"), res->ip, res->vname, icfg.SAB(tBytes), turl, LimitedURL(turl));
        Indics(stdout, tIndic);
    }

    SAfclose(Log);

    /* Add acript for RTR page autoupdate after timeout */
    SAfprintf(stdout, "\
<script language=\"JavaScript\" type=\"text/javascript\">\n\
\tvar t;\n\
\tfunction SAupdate() { top.location.href = \"free-sa.cgi?ldt=%ld\"; }\n\
\tfunction SAswitchbck() {\n\
\t\tif (t != 0) { clearTimeout(t); document.getElementById(\"bck\").src='../c.png'; t = 0; }\n\
\t\telse SAupdate();\n\
\t}\n\
\tt = setTimeout('SAupdate()', %ld);\n\
</script>\n", maxdate, cfg.real_time_timeout);

    SAfcloseH(stdout);

    return(EXIT_SUCCESS);
}
